TITLE     'Stress Concentration in a Shaft'		        { mex093.pde }
SELECT     errlim=1e-5     spectral_colors
COORDINATES     ycylinder( 'r', 'z')
VARIABLES     u     w
DEFINITIONS
   L=5e-3     d0=10e-3     p=1e8
   E=200e9     mu=0.3             			{ Steel }
   k1=0.1     k2=1.0					{ Input parameters }
   r0=k1*d0/(1+2*k1*k2)     h=k2*r0			{ Radius and depth }
   L0=sqrt(r0^2- [r0-h]^2)				{ Pythagoras }	
   snom=p*(d0/2)^2/ (d0/2-h)^2                 	{ Nominal stress }
#include 'defuw.pde'
EQUATIONS      						{ Multiplied by r: }
   u:	dr( r*sr)+ dz( r*srz)- st=0			
   w:	dr( r*srz)+ dz( r*sz)=0 		
BOUNDARIES
region 'steel'
   start 'outer' (0,-L)     load(w)=-r*p     line to (d0/2,-L)
   load(w)=0     line to (d0/2,-L0)
   arc to (d0/2-h,0) to (d0/2,L0)
   line to (d0/2,L)     load(w)=r*p     line to (0,L)
   value(u)=0     load(w)=0     line to (0,0)     point value(w)=0
   line to close
PLOTS
   grid( r+200*u, z+200*w)     contour( u)     contour( w)
   contour( uwm)     vector( uw) norm     elevation( u, w) on 'outer'
   contour( sr) painted     contour( st) painted     contour( sz) painted
   vector( cos(p_angl)*srp, sin(p_angl)*srp) norm notips as ' "tension" '
   contour( srp) painted     contour( szp) painted
   contour( mises) painted 	
   contour( mises/snom)    			{ Divided by nominal stress }
   contour( mises/snom) painted zoom(d0/2-1.5*h,-r0,  2*r0,2*r0)
      report( globalmax( mises)/snom)
END


